==> zio-aws-docdb_2.13-5.17.146.1-sources.jar: zio/aws/docdb/model/DeleteDbInstanceResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteDbInstanceResponse(
    dbInstance: Option[zio.aws.docdb.model.DBInstance] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DeleteDbInstanceResponse = {
    import DeleteDbInstanceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DeleteDbInstanceResponse
      .builder()
      .optionallyWith(dbInstance.map(value => value.buildAwsValue()))(
        _.dbInstance
      )
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.DeleteDbInstanceResponse.ReadOnly =
    zio.aws.docdb.model.DeleteDbInstanceResponse.wrap(buildAwsValue())
}
object DeleteDbInstanceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DeleteDbInstanceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.DeleteDbInstanceResponse =
      zio.aws.docdb.model
        .DeleteDbInstanceResponse(dbInstance.map(value => value.asEditable))
    def dbInstance: Option[zio.aws.docdb.model.DBInstance.ReadOnly]
    def getDbInstance
        : ZIO[Any, AwsError, zio.aws.docdb.model.DBInstance.ReadOnly] =
      AwsError.unwrapOptionField("dbInstance", dbInstance)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DeleteDbInstanceResponse
  ) extends zio.aws.docdb.model.DeleteDbInstanceResponse.ReadOnly {
    override val dbInstance: Option[zio.aws.docdb.model.DBInstance.ReadOnly] =
      scala
        .Option(impl.dbInstance())
        .map(value => zio.aws.docdb.model.DBInstance.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DeleteDbInstanceResponse
  ): zio.aws.docdb.model.DeleteDbInstanceResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-docdb_2.13-5.17.225.1-sources.jar: zio/aws/docdb/model/DeleteDbInstanceResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteDbInstanceResponse(
    dbInstance: Optional[zio.aws.docdb.model.DBInstance] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DeleteDbInstanceResponse = {
    import DeleteDbInstanceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DeleteDbInstanceResponse
      .builder()
      .optionallyWith(dbInstance.map(value => value.buildAwsValue()))(
        _.dbInstance
      )
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.DeleteDbInstanceResponse.ReadOnly =
    zio.aws.docdb.model.DeleteDbInstanceResponse.wrap(buildAwsValue())
}
object DeleteDbInstanceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DeleteDbInstanceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.DeleteDbInstanceResponse =
      zio.aws.docdb.model
        .DeleteDbInstanceResponse(dbInstance.map(value => value.asEditable))
    def dbInstance: Optional[zio.aws.docdb.model.DBInstance.ReadOnly]
    def getDbInstance
        : ZIO[Any, AwsError, zio.aws.docdb.model.DBInstance.ReadOnly] =
      AwsError.unwrapOptionField("dbInstance", dbInstance)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DeleteDbInstanceResponse
  ) extends zio.aws.docdb.model.DeleteDbInstanceResponse.ReadOnly {
    override val dbInstance: Optional[zio.aws.docdb.model.DBInstance.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbInstance())
        .map(value => zio.aws.docdb.model.DBInstance.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DeleteDbInstanceResponse
  ): zio.aws.docdb.model.DeleteDbInstanceResponse.ReadOnly = new Wrapper(impl)
}
